MethodChannelFlutterScreenCapture class
An implementation of FlutterScreenCapturePlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterScreenCapturePlatform
- MethodChannelFlutterScreenCapture
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startRecording(
) → Future< String> -
override
-
stopRecording(
) → Future< String> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
trimVideo(
String filePath, double startSeconds, double endSeconds) → Future< String> -
Trims a video file to the specified time range.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited