FlutterScreenCapturePlatform class abstract

The interface that implementations of screen_capture must implement.

Inheritance
  • Object
  • PlatformInterface
  • FlutterScreenCapturePlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startRecording() Future<String>
stopRecording() Future<String>
toString() String
A string representation of this object.
inherited
trimVideo(String filePath, double startSeconds, double endSeconds) Future<String>
Trims a video file to the specified time range.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterScreenCapturePlatform
getter/setter pair