trimVideo method
Trims a video file to the specified time range.
Implementation
Future<String> trimVideo(
String filePath, double startSeconds, double endSeconds) {
throw UnimplementedError('trimVideo() has not been implemented.');
}
Trims a video file to the specified time range.
Future<String> trimVideo(
String filePath, double startSeconds, double endSeconds) {
throw UnimplementedError('trimVideo() has not been implemented.');
}